@@ -26,6 +26,15 @@ def get_backend(settings, prefix="CONTAINER_HUB"):
         )
 
         return MarathonBackend(MarathonBackendConfig.from_settings(settings, prefix))
+    elif opt == "kubernetes":
+        from container_hub.carriers.kubernetes.backend import (
+            KubernetesBackend,
+            KubernetesBackendConfig,
+        )
+
+        return KubernetesBackend(
+            KubernetesBackendConfig.from_settings(settings, prefix)
+        )
 
     raise InvalidConfiguration(
         f"Unknown carrier {opt} option, should either be 'docker' or 'marathon'"
