@@ -1,9 +1,9 @@
 from __future__ import annotations
-import dataclasses
-from pathlib import Path
+import copy
 from dataclasses import dataclass, field, fields, _MISSING_TYPE
 from typing import List, Optional, Dict
 from enum import Enum
+from pathlib import Path
 from datetime import datetime
 from .exceptions import InvalidConfiguration
 from slugify import slugify
@@ -34,18 +34,18 @@ def create_klass(cls, settings, prefix: str):
     """
     kwargs = {}
 
-    for field in fields(cls):
-        attr_name = f"{prefix}_{field.name.upper()}"
+    for cls_field in fields(cls):
+        attr_name = f"{prefix}_{cls_field.name.upper()}"
 
         if (
-            isinstance(field.default, _MISSING_TYPE)
-            and isinstance(field.default_factory, _MISSING_TYPE)
+            isinstance(cls_field.default, _MISSING_TYPE)
+            and isinstance(cls_field.default_factory, _MISSING_TYPE)
             and not hasattr(settings, attr_name)
         ):
             raise InvalidConfiguration(f"{attr_name} is a mandatory setting")
 
         if hasattr(settings, attr_name):
-            kwargs[field.name] = getattr(settings, attr_name)
+            kwargs[cls_field.name] = getattr(settings, attr_name)
 
     # [['api', 'CLUSTER', 'v3'], ]
     if "constraints" in kwargs and isinstance(kwargs["constraints"], list):
@@ -158,6 +158,9 @@ class KubernetesContainer:
 
     @classmethod
     def from_dict(cls, values: Dict) -> "KubernetesContainer":
+        # Make (deep) copy to keep original defaults
+        values = copy.deepcopy(values)
+
         return KubernetesContainer(
             name=values.get("name"),
             image=values.get("image"),
@@ -174,6 +177,12 @@ class KubernetesContainer:
         )
 
 
+@dataclass
+class HostAlias:
+    ip_address: str
+    hostnames: List[str]
+
+
 @dataclass
 class KubernetesJobConfig:
     name: str
@@ -183,6 +192,8 @@ class KubernetesJobConfig:
     simulation_config: KubernetesContainer
     annotations: List[Label] = field(default_factory=list)
     labels: List[Label] = field(default_factory=list)
+    host_aliases: List[HostAlias] = field(default_factory=list)
+    service_account_name: str = "simulation-service-account"
 
     @property
     def mount_points(self) -> List[MountPoint]:
@@ -217,4 +228,8 @@ class KubernetesJobConfig:
                 cfg["SCHEDULER_WORKER"]
             ),
             simulation_config=KubernetesContainer.from_dict(cfg["SIMULATION"]),
+            host_aliases=[
+                HostAlias(ip_address, hostnames)
+                for ip_address, hostnames in cfg.get("HOST_ALIASES", {}).items()
+            ],
         )
